@@ -5,6 +5,12 @@ from scrapy import Request
 from scrapy.http import Response, TextResponse
 from scrapy.responsetypes import responsetypes
 
+from scrapy_zyte_api.utils import (
+    _RESPONSE_HAS_ATTRIBUTES,
+    _RESPONSE_HAS_IP_ADDRESS,
+    _RESPONSE_HAS_PROTOCOL,
+)
+
 _DEFAULT_ENCODING = "utf-8"
 
 
@@ -20,11 +26,29 @@ class ZyteAPIMixin:
     def __init__(self, *args, raw_api_response: Dict = None, **kwargs):
         super().__init__(*args, **kwargs)
         self._raw_api_response = raw_api_response
+        if not _RESPONSE_HAS_ATTRIBUTES:
+            self.attributes: Tuple[str, ...] = (
+                "url",
+                "status",
+                "headers",
+                "body",
+                "request",
+                "flags",
+                "certificate",
+            )
+            if _RESPONSE_HAS_IP_ADDRESS:
+                self.attributes += ("ip_address",)
+            if _RESPONSE_HAS_PROTOCOL:
+                self.attributes += ("protocol",)
+        self.attributes += ("raw_api_response",)
 
     def replace(self, *args, **kwargs):
         if kwargs.get("raw_api_response"):
             raise ValueError("Replacing the value of 'raw_api_response' isn't allowed.")
-        return super().replace(*args, **kwargs)
+        for attribute in self.attributes:
+            kwargs.setdefault(attribute, getattr(self, attribute))
+        cls = kwargs.pop("cls", self.__class__)
+        return cls(*args, **kwargs)
 
     @property
     def raw_api_response(self) -> Optional[Dict]:
@@ -47,9 +71,6 @@ class ZyteAPIMixin:
 
 
 class ZyteAPITextResponse(ZyteAPIMixin, TextResponse):
-
-    attributes: Tuple[str, ...] = TextResponse.attributes + ("raw_api_response",)
-
     @classmethod
     def from_api_response(cls, api_response: Dict, *, request: Request = None):
         """Alternative constructor to instantiate the response from the raw
@@ -75,11 +96,12 @@ class ZyteAPITextResponse(ZyteAPIMixin, TextResponse):
             raw_api_response=api_response,
         )
 
+    def replace(self, *args, **kwargs):
+        kwargs.setdefault("encoding", self.encoding)
+        return ZyteAPIMixin.replace(self, *args, **kwargs)
+
 
 class ZyteAPIResponse(ZyteAPIMixin, Response):
-
-    attributes: Tuple[str, ...] = Response.attributes + ("raw_api_response",)
-
     @classmethod
     def from_api_response(cls, api_response: Dict, *, request: Request = None):
         """Alternative constructor to instantiate the response from the raw
